package PoorBooru::Backend::Controller::Tags;
use v5.36;
use strict;
use warnings;

use Mojo::Base "Mojolicious::Controller";
use Mojo::JSON qw(decode_json);
use SeaweedFS::FID;

sub list ($self)
{
	my $v = $self->validation;
	my $page = $v->optional("page")->num(1, undef)->param // 1;

	return $self->render(status => 404) if $v->has_error;

	my $poorbooru_api = $self->config("poorbooru_api");
	my $res = $self->ua->get("$poorbooru_api/tags?page=$page")->result;

	return $self->render(status => $res->code) if $res->is_error;

	$self->title("tags");
	my @tags = map +{
		name  => $_->{name},
		count => $_->{count},
		uri   => $self->url_for("/tag/$_->{name}"),
	}, @{$res->json->{tags}};

	return $self->render(
		template => "tags",
		tags     => [ @tags ],
		pager    => { $self->pager_links($res->json->{pager}) },
	);
};

sub show ($self)
{

	my $v = $self->validation;
	my $page = $v->optional("page")->num(1, undef)->param // 1;

	return $self->render(status => 404) if $v->has_error;

	my $tag_id_or_name = $self->stash("tag_id_or_name");
	my $poorbooru_api = $self->config("poorbooru_api");
	my $res = $self->ua->get("$poorbooru_api/tag/$tag_id_or_name?page=$page")
	    ->result;

	return $self->render(status => $res->code) if $res->is_error;

	$self->title($res->json->{name});
	my @media = map +{
		media_src => $self->seaweed->url_for(
			SeaweedFS::FID->from_string($_->{seaweedfs_fid})
		),
	}, @{$res->json->{media}};

	return $self->render(
		template => "gallery",
		media    => [ @media ],
		pager    => { $self->pager_links($res->json->{pager}) },
	);
};

1;
